@@ -1,4 +1,5 @@
 """All internal ansible-lint rules."""
+
 from __future__ import annotations
 
 import copy
@@ -23,7 +24,7 @@ from ansiblelint._internal.rules import (
     WarningRule,
 )
 from ansiblelint.app import App, get_app
-from ansiblelint.config import PROFILES, Options, get_rule_config
+from ansiblelint.config import PROFILES, Options
 from ansiblelint.config import options as default_options
 from ansiblelint.constants import LINE_NUMBER_KEY, RULE_DOC_URL, SKIPPED_RULES_KEY
 from ansiblelint.errors import MatchError
@@ -55,11 +56,6 @@ class AnsibleLintRule(BaseRule):
         """Return rule documentation url."""
         return RULE_DOC_URL + self.id + "/"
 
-    @property
-    def rule_config(self) -> dict[str, Any]:
-        """Retrieve rule specific configuration."""
-        return get_rule_config(self.id)
-
     def get_config(self, key: str) -> Any:
         """Return a configured value for given key string."""
         return self.rule_config.get(key, None)
@@ -97,7 +93,7 @@ class AnsibleLintRule(BaseRule):
         match_type: str | None = None
         while not match_type and frame is not None:
             func_name = frame.f_code.co_name
-            match_type = match_types.get(func_name, None)
+            match_type = match_types.get(func_name)
             if match_type:
                 # add the match_type to the match
                 match.match_type = match_type
@@ -228,7 +224,16 @@ class AnsibleLintRule(BaseRule):
         if isinstance(yaml, str):
             if yaml.startswith("$ANSIBLE_VAULT"):
                 return []
-            return [MatchError(lintable=file, rule=LoadingFailureRule())]
+            if self._collection is None:
+                msg = f"Rule {self.id} was not added to a collection."
+                raise RuntimeError(msg)
+            return [
+                # pylint: disable=E1136
+                MatchError(
+                    lintable=file,
+                    rule=self._collection["load-failure"],
+                ),
+            ]
         if not yaml:
             return matches
 
@@ -328,7 +333,6 @@ class TransformMixin:
         return target
 
 
-# pylint: disable=too-many-nested-blocks
 def load_plugins(
     dirs: list[str],
 ) -> Iterator[AnsibleLintRule]:
@@ -409,6 +413,8 @@ class RulesCollection:
                 WarningRule(),
             ],
         )
+        for rule in self.rules:
+            rule._collection = self  # noqa: SLF001
         for rule in load_plugins(rulesdirs_str):
             self.register(rule, conditional=conditional)
         self.rules = sorted(self.rules)
@@ -447,6 +453,14 @@ class RulesCollection:
         """Return the length of the RulesCollection data."""
         return len(self.rules)
 
+    def __getitem__(self, item: Any) -> BaseRule:
+        """Return a rule from inside the collection based on its id."""
+        for rule in self.rules:
+            if rule.id == item:
+                return rule
+        msg = f"Rule {item} is not present inside this collection."
+        raise ValueError(msg)
+
     def extend(self, more: list[AnsibleLintRule]) -> None:
         """Combine rules."""
         self.rules.extend(more)
@@ -473,7 +487,7 @@ class RulesCollection:
                     MatchError(
                         message=str(exc),
                         lintable=file,
-                        rule=LoadingFailureRule(),
+                        rule=self["load-failure"],
                         tag=f"{LoadingFailureRule.id}[{exc.__class__.__name__.lower()}]",
                     ),
                 ]
@@ -486,10 +500,13 @@ class RulesCollection:
                 or rule.has_dynamic_tags
                 or not set(rule.tags).union([rule.id]).isdisjoint(tags)
             ):
+                _logger.debug("Running rule %s", rule.id)
                 rule_definition = set(rule.tags)
                 rule_definition.add(rule.id)
                 if set(rule_definition).isdisjoint(skip_list):
                     matches.extend(rule.getmatches(file))
+            else:
+                _logger.debug("Skipping rule %s", rule.id)
 
         # some rules can produce matches with tags that are inside our
         # skip_list, so we need to cleanse the matches
@@ -541,7 +558,7 @@ class RulesCollection:
                 tags[tag] = list(rule.ids())
         result = "# List of tags and rules they cover\n"
         for tag in sorted(tags):
-            desc = tag_desc.get(tag, None)
+            desc = tag_desc.get(tag)
             if desc:
                 result += f"{tag}:  # {desc}\n"
             else:
@@ -562,6 +579,8 @@ def filter_rules_with_profile(rule_col: list[BaseRule], profile: str) -> None:
             included.add(rule)
         extends = PROFILES[extends].get("extends", None)
     for rule in rule_col.copy():
+        if rule.unloadable:
+            continue
         if rule.id not in included:
             _logger.debug(
                 "Unloading %s rule due to not being part of %s profile.",
