@@ -15,17 +15,25 @@
 """NoLogPasswordsRule used with ansible-lint."""
 from __future__ import annotations
 
+import os
 import sys
-from typing import TYPE_CHECKING, Any
+from pathlib import Path
+from typing import TYPE_CHECKING
 
-from ansiblelint.rules import AnsibleLintRule
-from ansiblelint.utils import convert_to_boolean
+from ansiblelint.rules import AnsibleLintRule, RulesCollection, TransformMixin
+from ansiblelint.runner import get_matches
+from ansiblelint.transformer import Transformer
+from ansiblelint.utils import Task, convert_to_boolean
 
 if TYPE_CHECKING:
+    from ruamel.yaml.comments import CommentedMap, CommentedSeq
+
+    from ansiblelint.config import Options
+    from ansiblelint.errors import MatchError
     from ansiblelint.file_utils import Lintable
 
 
-class NoLogPasswordsRule(AnsibleLintRule):
+class NoLogPasswordsRule(AnsibleLintRule, TransformMixin):
     """Password should not be logged."""
 
     id = "no-log-password"
@@ -38,14 +46,16 @@ class NoLogPasswordsRule(AnsibleLintRule):
     version_added = "v5.0.9"
 
     def matchtask(
-        self, task: dict[str, Any], file: Lintable | None = None
+        self,
+        task: Task,
+        file: Lintable | None = None,
     ) -> bool | str:
         if task["action"]["__ansible_module_original__"] == "ansible.builtin.user" and (
             task["action"].get("password_lock") and not task["action"].get("password")
         ):
             has_password = False
         else:
-            for param in task["action"].keys():
+            for param in task["action"]:
                 if "password" in param:
                     has_password = True
                     break
@@ -67,14 +77,29 @@ class NoLogPasswordsRule(AnsibleLintRule):
             return False
 
         return bool(
-            has_password and not convert_to_boolean(no_log) and len(has_loop) > 0
+            has_password and not convert_to_boolean(no_log) and len(has_loop) > 0,
         )
 
+    def transform(
+        self,
+        match: MatchError,
+        lintable: Lintable,
+        data: CommentedMap | CommentedSeq | str,
+    ) -> None:
+        if match.tag == self.id:
+            task = self.seek(match.yaml_path, data)
+            task["no_log"] = True
+
+            match.fixed = True
+
+
+if "pytest" in sys.modules:
+    from unittest import mock
 
-if "pytest" in sys.modules:  # noqa: C901
     import pytest
 
-    from ansiblelint.testing import RunFromText  # pylint: disable=ungrouped-imports
+    if TYPE_CHECKING:
+        from ansiblelint.testing import RunFromText
 
     NO_LOG_UNUSED = """
 - name: Test
@@ -209,7 +234,9 @@ if "pytest" in sys.modules:  # noqa: C901
 """
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_unused(rule_runner: RunFromText) -> None:
         """The task does not use no_log but also no loop."""
@@ -217,7 +244,9 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_false(rule_runner: RunFromText) -> None:
         """The task sets no_log to false."""
@@ -227,7 +256,9 @@ if "pytest" in sys.modules:  # noqa: C901
             assert result.rule.id == "no-log-password"
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_no(rule_runner: RunFromText) -> None:
         """The task sets no_log to no."""
@@ -236,7 +267,9 @@ if "pytest" in sys.modules:  # noqa: C901
         assert results[0].rule.id == "no-log-password"
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_password_with_lock(rule_runner: RunFromText) -> None:
         """The task sets a password but also lock the user."""
@@ -245,7 +278,9 @@ if "pytest" in sys.modules:  # noqa: C901
         assert results[0].rule.id == "no-log-password"
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_yes(rule_runner: RunFromText) -> None:
         """The task sets no_log to yes."""
@@ -253,7 +288,9 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_true(rule_runner: RunFromText) -> None:
         """The task sets no_log to true."""
@@ -261,7 +298,9 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_password_lock_yes(rule_runner: RunFromText) -> None:
         """The task only locks the user."""
@@ -269,7 +308,9 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_no_log_password_lock_yes_but_no_password(rule_runner: RunFromText) -> None:
         """The task only locks the user."""
@@ -277,9 +318,41 @@ if "pytest" in sys.modules:  # noqa: C901
         assert len(results) == 0
 
     @pytest.mark.parametrize(
-        "rule_runner", (NoLogPasswordsRule,), indirect=["rule_runner"]
+        "rule_runner",
+        (NoLogPasswordsRule,),
+        indirect=["rule_runner"],
     )
     def test_password_lock_false(rule_runner: RunFromText) -> None:
         """The task does not actually lock the user."""
         results = rule_runner.run_playbook(PASSWORD_LOCK_FALSE)
         assert len(results) == 0
+
+    @mock.patch.dict(os.environ, {"ANSIBLE_LINT_WRITE_TMP": "1"}, clear=True)
+    def test_no_log_password_transform(
+        config_options: Options,
+    ) -> None:
+        """Test transform functionality for no-log-password rule."""
+        playbook = Path("examples/playbooks/transform-no-log-password.yml")
+        config_options.write_list = ["all"]
+        rules = RulesCollection(options=config_options)
+        rules.register(NoLogPasswordsRule())
+
+        config_options.lintables = [str(playbook)]
+        runner_result = get_matches(rules=rules, options=config_options)
+        transformer = Transformer(result=runner_result, options=config_options)
+        transformer.run()
+
+        matches = runner_result.matches
+        assert len(matches) == 2
+
+        orig_content = playbook.read_text(encoding="utf-8")
+        expected_content = playbook.with_suffix(
+            f".transformed{playbook.suffix}",
+        ).read_text(encoding="utf-8")
+        transformed_content = playbook.with_suffix(f".tmp{playbook.suffix}").read_text(
+            encoding="utf-8",
+        )
+
+        assert orig_content != transformed_content
+        assert expected_content == transformed_content
+        playbook.with_suffix(f".tmp{playbook.suffix}").unlink()
