@@ -1,4 +1,5 @@
 """Runner implementation."""
+
 from __future__ import annotations
 
 import json
@@ -47,8 +48,7 @@ from ansiblelint.utils import (
 )
 
 if TYPE_CHECKING:
-    from collections.abc import Generator
-    from typing import Callable
+    from collections.abc import Callable, Generator
 
     from ansiblelint.config import Options
     from ansiblelint.constants import FileType
@@ -184,9 +184,9 @@ class Runner:
                     else:
                         filename = warn.source
                         match = MatchError(
-                            message=warn.message
-                            if isinstance(warn.message, str)
-                            else "?",
+                            message=(
+                                warn.message if isinstance(warn.message, str) else "?"
+                            ),
                             rule=self.rules["warning"],
                             filename=str(filename),
                         )
